==> haskell-src-1.0.4.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-src
version:              1.0.4.1
visibility:           public
id:                   haskell-src-1.0.4.1-GpeSq9M9iD08ND0JwzMXGp
key:                  haskell-src-1.0.4.1-GpeSq9M9iD08ND0JwzMXGp
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Simon Marlow, Sven Panne and Noel Winstanley
stability:            stable
synopsis:             Support for manipulating Haskell source code
description:
    The @haskell-src@ package provides support for manipulating Haskell
    source code. The package provides a lexer, parser and
    pretty-printer, and a definition of a Haskell abstract syntax tree
    (AST). Common uses of this package are to parse or generate
    <http://www.haskell.org/onlinereport/ Haskell 98> code.

category:             Language
abi:                  1977e6a1e0f1761651dcf65d7c444357
exposed:              True
exposed-modules:
    Language.Haskell.Lexer Language.Haskell.ParseMonad
    Language.Haskell.ParseUtils Language.Haskell.Parser
    Language.Haskell.Pretty Language.Haskell.Syntax

import-dirs:          /usr/lib/ghc-9.2.8/site-local/haskell-src-1.0.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/haskell-src-1.0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src
hs-libraries:         HShaskell-src-1.0.4.1-GpeSq9M9iD08ND0JwzMXGp
depends:
    array-0.5.4.0 base-4.16.4.0 pretty-1.1.3.6
    syb-0.7.2.4-7ynUdJcB17N8mF8LpyS12V

haddock-interfaces:   /usr/share/doc/haskell-src/html/haskell-src.haddock
haddock-html:         /usr/share/doc/haskell-src/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-1.0.4.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src
version:              1.0.4.1
visibility:           public
id:                   haskell-src-1.0.4.1-6ADz5uZKwgzAsyUC0W6YH5
key:                  haskell-src-1.0.4.1-6ADz5uZKwgzAsyUC0W6YH5
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Simon Marlow, Sven Panne and Noel Winstanley
stability:            stable
synopsis:             Support for manipulating Haskell source code
description:
    The @haskell-src@ package provides support for manipulating Haskell
    source code. The package provides a lexer, parser and
    pretty-printer, and a definition of a Haskell abstract syntax tree
    (AST). Common uses of this package are to parse or generate
    <http://www.haskell.org/onlinereport/ Haskell 98> code.

category:             Language
abi:                  1718441b7945b15d85883809283aa2dc
exposed:              True
exposed-modules:
    Language.Haskell.Lexer Language.Haskell.ParseMonad
    Language.Haskell.ParseUtils Language.Haskell.Parser
    Language.Haskell.Pretty Language.Haskell.Syntax

import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-src-1.0.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-src-1.0.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-src-1.0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src
hs-libraries:         HShaskell-src-1.0.4.1-6ADz5uZKwgzAsyUC0W6YH5
depends:
    array-0.5.4.0 base-4.17.2.1 pretty-1.1.3.6
    syb-0.7.2.4-GwVxHFFp6zLBbNId74rfEd

haddock-interfaces:   /usr/share/doc/haskell-src/html/haskell-src.haddock
haddock-html:         /usr/share/doc/haskell-src/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
